@@ -1,6 +1,4 @@
-
-/*    $OpenBSD: getopt_long.c,v 1.17 2004/06/03 18:46:52 millert Exp $    */
-/*    $NetBSD: getopt_long.c,v 1.15 2002/01/31 22:43:40 tv Exp $    */
+/*      $OpenBSD: getopt_long.c,v 1.20 2005/10/25 15:49:37 jmc Exp $    */
 
 /*
  * Copyright (c) 2002 Todd C. Miller <Todd.Miller@courtesan.com>
@@ -112,13 +110,13 @@ static const char *illoptstring = "unknown option -- %s\n";
 static int pure_gcd(int a, int b)
 {
     int c;
-
+    
     c = a % b;
     while (c != 0) {
         a = b;
         b = c;
         c = a % b;
-    }
+    }    
     return b;
 }
 
@@ -127,12 +125,12 @@ static int pure_gcd(int a, int b)
  * from nonopt_end to opt_end (keeping the same order of arguments
  * in each block).
  */
-static void pure_permute_args(int panonopt_start, int panonopt_end,
+static void pure_permute_args(int panonopt_start, int panonopt_end, 
                               int opt_end, char * const *nargv)
 {
     int cstart, cyclelen, i, j, ncycle, nnonopts, nopts, pos;
     char *swap;
-
+    
     /*
      * compute lengths of blocks and number and size of cycles
      */
@@ -140,7 +138,7 @@ static void pure_permute_args(int panonopt_start, int panonopt_end,
     nopts = opt_end - panonopt_end;
     ncycle = pure_gcd(nnonopts, nopts);
     cyclelen = (opt_end - panonopt_start) / ncycle;
-
+    
     for (i = 0; i < ncycle; i++) {
         cstart = panonopt_end+i;
         pos = cstart;
@@ -170,25 +168,25 @@ static int pure_parse_long_options(char * const *nargv, const char *options,
     const char *current_argv, *has_equal;
     size_t current_argv_len;
     int i, match;
-
+    
     current_argv = pure_place;
     match = -1;
-
+    
     pure_optind++;
-
+    
     if ((has_equal = strchr(current_argv, '=')) != NULL) {
         /* argument found (--option=arg) */
         current_argv_len = has_equal - current_argv;
         has_equal++;
     } else
         current_argv_len = strlen(current_argv);
-
+    
     for (i = 0; long_options[i].name; i++) {
         /* find matching long option */
         if (strncmp(current_argv, long_options[i].name,
             current_argv_len))
             continue;
-
+        
         if (strlen(long_options[i].name) == current_argv_len) {
             /* exact match */
             match = i;
@@ -200,7 +198,7 @@ static int pure_parse_long_options(char * const *nargv, const char *options,
          */
         if (short_too && current_argv_len == 1)
             continue;
-
+        
         if (match == -1)    /* partial match */
             match = i;
         else {
@@ -289,10 +287,10 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
     char *oli;                /* option letter list index */
     int optchar, short_too;
     static int posixly_correct = -1;
-
+    
     if (options == NULL)
         return -1;
-
+    
     /*
      * Disable GNU extensions if POSIXLY_CORRECT is set or options
      * string begins with a '+'.
@@ -305,14 +303,14 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
         flags |= FLAG_ALLARGS;
     if (*options == '+' || *options == '-')
         options++;
-
+    
     /*
      * XXX Some GNU programs (like cvs) set pure_optind to 0 instead of
      * XXX using pure_optreset.  Work around this braindamage.
      */
     if (pure_optind == 0)
         pure_optind = pure_optreset = 1;
-
+    
     pure_optarg = NULL;
     if (pure_optreset)
         nonopt_start = nonopt_end = -1;
@@ -394,7 +392,7 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
             return -1;
         }
     }
-
+    
     /*
      * Check long options if:
      *  1) we were passed some
@@ -408,7 +406,7 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
             pure_place++;        /* --foo long option */
         else if (*pure_place != ':' && strchr(options, *pure_place) != NULL)
             short_too = 1;        /* could be short option too */
-
+        
         optchar = pure_parse_long_options(nargv, options, long_options,
                                           idx, short_too);
         if (optchar != -1) {
@@ -416,17 +414,17 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
             return optchar;
         }
     }
-
+    
     if ((optchar = (int) *pure_place++) == ':' ||
-        optchar == '-' && *pure_place != '\0' ||
-        (oli = strchr(options, optchar)) == NULL) {
+        optchar == '-' && *pure_place != '\0' ||        
+        (oli = strchr(options, optchar)) == NULL) { 
          /*
-          * If the user specified "-" and '-' isn't listed in
-          * options, return -1 (non-option) as per POSIX.
-          * Otherwise, it is an unknown option character (or :').
+          * If the user didn't specify '-' as an option,
+	  * assume it means -1 as POSIX specifies.
           */
-        if (optchar == '-' && *pure_place == '\0')
+        if (optchar == '-')
             return -1;
+	/* option letter unknown or ':' */
         if (!*pure_place)
             ++pure_optind;
         if (PRINT_ERROR)
@@ -456,29 +454,29 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
             ++pure_optind;
     } else {                /* takes (optional) argument */
         pure_optarg = NULL;
-        if (*pure_place)            /* no white space */
-            pure_optarg = pure_place;
-        /* XXX: disable test for :: if PC? (GNU doesn't) */
-        else if (oli[1] != ':') {    /* arg not optional */
+        if (*pure_place) {            /* no white space */
+	    pure_optarg = pure_place;
+	    /* XXX: disable test for :: if PC? (GNU doesn't) */
+        } else if (oli[1] != ':') {    /* arg not optional */
             if (++pure_optind >= nargc) {    /* no arg */
                 pure_place = EMSG;
                 if (PRINT_ERROR)
                     fprintf(stderr, recargchar, optchar);
                 pure_optopt = optchar;
                 return BADARG;
-            } else if (!(flags & FLAG_PERMUTE)) {
-                /*
-                 * If permutation is disabled, we can accept an
-                 * optional arg separated by whitespace so long
-                 * as it does not start with a dash (-).
-                 */
-                 if (pure_optind + 1 < nargc && pure_optind + 1 > 0 &&
-                     *nargv[pure_optind + 1] != '-') {
-                     pure_optarg = nargv[++pure_optind];
-                 }
-            } else {
-                pure_optarg = nargv[pure_optind];
-            }
+	    } else {
+		pure_optarg = nargv[pure_optind];
+	    }
+	} else if (!(flags & FLAG_PERMUTE)) {
+	    /* 
+	     * If permutation is disabled, we can accept an
+	     * optional arg separated by whitespace so long
+	     * as it does not start with a dash (-).
+	     */
+	    if (pure_optind + 1 < nargc &&
+		*nargv[pure_optind + 1] != '-') {
+		pure_optarg = nargv[++pure_optind];
+	    }
         }
         pure_place = EMSG;
         ++pure_optind;
@@ -493,9 +491,9 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
  */
 int pure_getopt(int nargc, char * const *nargv, const char *options)
 {
-
+    
     /*
-     * We dont' pass FLAG_PERMUTE to pure_getopt_internal() since
+     * We don't pass FLAG_PERMUTE to pure_getopt_internal() since
      * the BSD getopt(3) (unlike GNU) has never done this.
      *
      * Furthermore, since many privileged programs call getopt()
